package com.mkyong;

import java.util.Date;

import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.transaction.HeuristicMixedException;
import javax.transaction.HeuristicRollbackException;
import javax.transaction.NotSupportedException;
import javax.transaction.RollbackException;
import javax.transaction.SystemException;
import javax.transaction.UserTransaction;

import org.drools.KnowledgeBase;
import org.drools.KnowledgeBaseFactory;
import org.drools.marshalling.ObjectMarshallingStrategy;
import org.drools.marshalling.impl.ClassObjectMarshallingStrategyAcceptor;
import org.drools.marshalling.impl.SerializablePlaceholderResolverStrategy;
import org.drools.persistence.jpa.KnowledgeStoreService;
import org.drools.persistence.jpa.marshaller.JPAPlaceholderResolverStrategy;
import org.drools.runtime.Environment;
import org.drools.runtime.EnvironmentName;
import org.drools.runtime.StatefulKnowledgeSession;
import org.hibernate.Session;
import org.springframework.context.ApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import bitronix.tm.BitronixTransactionManager;
import bitronix.tm.TransactionManagerServices;

import com.mkyong.stock.Stock;
import com.mkyong.stock.StockDailyRecord;
import com.mkyong.util.HibernateUtil;

public class LilyApp {
	
	 private static final String APPLICATION_CONTEXT_XML = "ApplicationContext.xml";
	 private static ApplicationContext context;
	 private static StatefulKnowledgeSession session;
	 
	public static void main(String[] args) throws Exception {
		System.out.println("Hibernate one to many (Annotation)");
	//	Session session = HibernateUtil.getSessionFactory().openSession();

	//	session.beginTransaction();
		
		context = new ClassPathXmlApplicationContext(APPLICATION_CONTEXT_XML);
    	
    	KnowledgeStoreService kstore = (KnowledgeStoreService) context.getBean("CAREKnowledgeStore");
    	Environment env = KnowledgeBaseFactory.newEnvironment();
	    	
    	env.set(EnvironmentName.ENTITY_MANAGER_FACTORY, context.getBean("entityManagerFactory"));
   
    	BitronixTransactionManager transactionManager= TransactionManagerServices.getTransactionManager();
         
        try {
        	UserTransaction ut = (UserTransaction) new InitialContext().lookup("java:comp/UserTransaction");
        	ut.begin();
 		//	transactionManager.begin();
 			env.set( EnvironmentName.TRANSACTION_MANAGER, transactionManager);
 		    env.set(EnvironmentName.OBJECT_MARSHALLING_STRATEGIES, new ObjectMarshallingStrategy[]{
 		                new JPAPlaceholderResolverStrategy(env),
 		                new SerializablePlaceholderResolverStrategy
 		                (ClassObjectMarshallingStrategyAcceptor.DEFAULT)});

    	session = kstore.newStatefulKnowledgeSession((KnowledgeBase)context.getBean("CAREEngineKBase"), null, env);

		Stock stock = new Stock();
        stock.setStockCode("7052");
        stock.setStockName("Lily");
        session.insert(stock);
        
        StockDailyRecord stockDailyRecords = new StockDailyRecord();
        stockDailyRecords.setPriceOpen(new Float("1.2"));
        stockDailyRecords.setPriceClose(new Float("1.1"));
        stockDailyRecords.setPriceChange(new Float("10.0"));
        stockDailyRecords.setVolume(3000000L);
        stockDailyRecords.setDate(new Date());
        
        stockDailyRecords.setStock(stock);        
        stock.getStockDailyRecords().add(stockDailyRecords);

        session.insert(stockDailyRecords);

        ut.commit();
		System.out.println("Done");
		
         } catch (SecurityException | IllegalStateException | RollbackException
 				| HeuristicMixedException | HeuristicRollbackException e) {
 			// TODO Auto-generated catch block
 			e.printStackTrace();
          } catch (SystemException e) {
  			// TODO Auto-generated catch block
  			e.printStackTrace();
  			
  		}
	}
}
